@@ -1466,7 +1466,6 @@ def init_diagonostic():
     assert len(hex_token) == 64
     url_safe_token = token_generate(32, return_type="URL")
     print ("url safe token:", url_safe_token)
-    print (len(url_safe_token))
     assert len(url_safe_token) == 43
     print ("test complete; token generation function passed")
     print ("testing secure file deletion function")
@@ -1477,7 +1476,6 @@ def init_diagonostic():
     test_file.close()
     # deleting using secure file deletion function
     exit_code = sec_delete("test_file.txt")
-    print(exit_code)
     # checking if file is deleted
     assert not os.path.exists("test_file.txt")
     print ("test complete; secure file deletion function passed")
@@ -1588,7 +1586,8 @@ def init_diagonostic():
     # decrypting the string
     decrypted_string = cipher.FerNet_decrypt_string(encrypted_string, key=decrypt_key)
     # checking if the decrypted string is the same as the original
-    assert decrypted_string.decode() == "Hello World"
+    print (decrypted_string)
+    assert decrypted_string == b"Hello World"
     # deleting all variables and test files
     for i in globals():
         del globals()[i]
